<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: input.proto

namespace OS\PB;

use Google\Protobuf\Internal\GPBType;
use Google\Protobuf\Internal\GPBUtil;
use Google\Protobuf\RepeatedField;

/**
 * Generated from protobuf message <code>OS.PB.InputConfig</code>
 */
class InputConfig extends \Google\Protobuf\Internal\Message
{
    /**
     * Generated from protobuf field <code>.OS.PB.Toggle Invert = 1;</code>
     */
    protected $Invert = 0;
    /**
     * Generated from protobuf field <code>.OS.PB.Toggle EOLSensing = 2;</code>
     */
    protected $EOLSensing = 0;
    /**
     * Generated from protobuf field <code>uint32 DebouncePeriod = 5;</code>
     */
    protected $DebouncePeriod = 0;

    /**
     * Constructor.
     *
     * @param array $data {
     *     Optional. Data for populating the Message object.
     *
     *     @type int $Invert
     *     @type int $EOLSensing
     *     @type int $DebouncePeriod
     * }
     */
    public function __construct($data = NULL) {
        \GPBMetadata\Input::initOnce();
        parent::__construct($data);
    }

    /**
     * Generated from protobuf field <code>.OS.PB.Toggle Invert = 1;</code>
     * @return int
     */
    public function getInvert()
    {
        return $this->Invert;
    }

    /**
     * Generated from protobuf field <code>.OS.PB.Toggle Invert = 1;</code>
     * @param int $var
     * @return $this
     */
    public function setInvert($var)
    {
        GPBUtil::checkEnum($var, \OS\PB\Toggle::class);
        $this->Invert = $var;

        return $this;
    }

    /**
     * Generated from protobuf field <code>.OS.PB.Toggle EOLSensing = 2;</code>
     * @return int
     */
    public function getEOLSensing()
    {
        return $this->EOLSensing;
    }

    /**
     * Generated from protobuf field <code>.OS.PB.Toggle EOLSensing = 2;</code>
     * @param int $var
     * @return $this
     */
    public function setEOLSensing($var)
    {
        GPBUtil::checkEnum($var, \OS\PB\Toggle::class);
        $this->EOLSensing = $var;

        return $this;
    }

    /**
     * Generated from protobuf field <code>uint32 DebouncePeriod = 5;</code>
     * @return int
     */
    public function getDebouncePeriod()
    {
        return $this->DebouncePeriod;
    }

    /**
     * Generated from protobuf field <code>uint32 DebouncePeriod = 5;</code>
     * @param int $var
     * @return $this
     */
    public function setDebouncePeriod($var)
    {
        GPBUtil::checkUint32($var);
        $this->DebouncePeriod = $var;

        return $this;
    }

}

